// Copyright 2001, 2002 by Jon Dart. All Rights Reserved
#ifndef _GUIOPTS_H
#define _GUIOPTS_H

#include "timectrl.h"
#include "searchop.h"

// This class holds information on user preferences for the GUI.
// These preferences are saved into the system registry.

class CWinApp;

struct GeneralPreferences
{
   BOOL beep_after_move;
   BOOL beep_on_error;
   BOOL can_resign;
   BOOL think_when_idle;
   int hash_table_size;
   BOOL auto_size_hash_table;
};

class GuiOptions {

public:

   enum BoardSize { Small, Medium, Large, XLarge };

   struct Appearance
   {
      BOOL show_coordinates;
      string pieceFontName;
      BoardSize board_size;
      COLORREF lightSquareColor, darkSquareColor;
      BOOL forceMono;
   };

   GuiOptions(CWinApp *);

   const Search_Limit_Options &get_src_limits() const {
      return src_opts;
   }

   void set_src_limits(const Search_Limit_Options &new_opts) {
      src_opts = new_opts;
   }

   BOOL beep_after_move() const
   {
      return gprefs.beep_after_move;	   
   }
	
   BOOL beep_on_error() const
   {
      return gprefs.beep_on_error;
   }
	
   BOOL can_resign() const
   {
      return gprefs.can_resign;
   }
	
   BOOL think_when_idle() const
   {
      return gprefs.think_when_idle;
   }

   BOOL show_coordinates() const {
      return appr.show_coordinates;
   }

   void setShowCoordinates(BOOL value) {
      appr.show_coordinates = value;
   }

   int hash_table_size() const {
      return gprefs.hash_table_size;
   }

   BOOL auto_size_hash_table() const {
      return gprefs.auto_size_hash_table;
   }

   void getGeneralPreferences(GeneralPreferences &prefs) {
      prefs = gprefs;
   }

   void setGeneralPreferences(const GeneralPreferences &prefs) {
     gprefs = prefs;
   }
   
   void save();

   void set_app_location(int x, int y);

   void get_app_location(int &x, int &y);

   LPCSTR getPieceFontName() const {
      return appr.pieceFontName.c_str();
   }

   void setPieceFontName(LPCSTR font) {
      appr.pieceFontName = font;
   }

   void setBoardSize(BoardSize size) {
       appr.board_size = size;
   }

   const BoardSize getBoardSize() const {
       return appr.board_size;
   }

   const COLORREF getLightSquareColor() const {
      return appr.lightSquareColor;
   }

   const void setLightSquareColor(COLORREF color) {
      appr.lightSquareColor = color;
   }

   const COLORREF getDarkSquareColor() const {
      return appr.darkSquareColor;
   }

   const void setDarkSquareColor(COLORREF color) {
      appr.darkSquareColor = color;
   }

   const BOOL getForceMono() {
      return appr.forceMono;
   }
 
   void setForceMono(BOOL flag) {
      appr.forceMono = flag;
   }
   
private:
   void load_src_limits();
   void store_src_limits();

   Search_Limit_Options src_opts;
   GeneralPreferences gprefs;
   Appearance appr;
   CWinApp *app;
   int appX, appY;
};

extern int calc_hash_size();

#endif
