// Copyright 1996-2008 by Jon Dart.  All Rights Reserved.

#include "globals.h"
#include "hash.h"
#include "bitprobe.h"
#include "scoring.h"
#include "tbprobe.h"

char cmd_buf[CMD_BUF_SIZE];
int cmd_buf_count;
int EGTBMenCount = 0;
MoveArray *gameMoves;
Options options;
Book *openingBook = NULL;
Log *theLog = NULL;
string learnFileName;

#define LEARN_FILE_NAME "arasan.lrn"

string programPath;

string derivePath(const char *fileName) {
   return derivePath(programPath.c_str(),fileName);
}

string derivePath(const char *base, const char *fileName) {
    string result(base);
    size_t pos;
#ifdef _WIN32
    pos = result.rfind('\\',string::npos);
#else
    pos = result.rfind('/',string::npos);
#endif
    if (pos == string::npos) {
      return fileName;
    }
    else {
      return result.substr(0,pos+1) + fileName;
    }
}

int initGlobals(const char *pathName, int initBitbases) {
  programPath = pathName;
  gameMoves = new MoveArray();
  theLog = new Log();
  theLog->clear();
  theLog->write_header();
  if (initBitbases) {
    int ret= initBitbase();
    if (!ret)
      cerr << "Error: required bitbase files not found." << endl;
    return ret;
  }
  else
    return 1;
}

void CDECL cleanupGlobals(void) {
  delete openingBook;
  delete gameMoves;
  delete theLog;
}

void initOptions(const char *pathName) {
    programPath = pathName;
    string rcPath = derivePath("arasan.rc");
    // try to read arasan.rc file
    options.init(rcPath);
#ifndef _WIN32
    // Also read .rc from the user's HOME,
    // if there is one.
    if (getenv("HOME")) {
       rcPath = derivePath(getenv("HOME"),"arasan.rc");
       options.init(rcPath);       
    }
#endif
    learnFileName = derivePath(LEARN_FILE_NAME);
}

void delayedInit() {
    // If no tablebase directory was specified in the .rc file,
    // try to find the table bases under the arasan install dir
    if (options.search.use_tablebases &&
        options.search.tablebase_location == "") {
       options.search.tablebase_location=derivePath("TB");
    }
    if (options.search.use_tablebases) {
       EGTBMenCount = initTB((char*)options.search.tablebase_location.c_str(),
         options.search.tb_cache_size);
    }
    // also initialize the book here
    if (options.book.book_enabled) {
       openingBook = new Book();
    }
}
